/**
 *
 * SIROCCO
 * Copyright (C) 2011 France Telecom
 * Contact: sirocco@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 *  $Id: XenDriver.java 598 2011-11-02 17:53:02Z dangtran $
 *
 */

package org.ow2.sirocco.vmm.agent.driver.xenapi;

import java.util.Map;

import javax.management.ObjectName;

import org.ow2.sirocco.vmm.agent.domain.ServerPool;
import org.ow2.sirocco.vmm.agent.driver.Driver;
import org.ow2.sirocco.vmm.api.BadVMPowerStateException;
import org.ow2.sirocco.vmm.api.VMMException;

import com.xensource.xenapi.Types;

/**
 * XenAPI driver implementation.
 */
public class XenDriver implements Driver {
    private static String[] attributes = {"user", "password", "master", "port"};

    public static String NAME = "xenapi";

    static final String CUSTOMIZE_DISK_SCRIPT = "customizeGuestOS.sh";

    public ServerPool newServerPool(final String name, final ObjectName objectName, final Map<String, String> attributes)
        throws IllegalArgumentException {
        XenServerPool pool = new XenServerPool(name, objectName, attributes);
        return pool;
    }

    @Override
    public String getName() {
        return XenDriver.NAME;
    }

    @Override
    public String[] getServerPoolCreationAttributes() {
        return XenDriver.attributes;
    }

    static VMMException translateXenAPIException(final Exception ex) {
        XenVirtualMachine.logger.error("XenAPI exception: ", ex);
        if (ex instanceof Types.VmBadPowerState) {
            return new BadVMPowerStateException(ex.toString());
        }
        return new VMMException(ex.toString());
    }

}
